#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_UPLUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_UPLUS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/uplus.hpp>

#endif
